@@ -5,7 +5,7 @@
 **
 ** Dump AH payload
 **
-** $Id: ah.c,v 1.8 2001/04/02 17:41:01 mborella Exp $
+** $Id: ah.c,v 1.9 2001/05/28 19:24:04 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -49,6 +49,9 @@ void dump_ah(packet_t *pkt)
   u_int8_t    next;
   u_int16_t   reserved;
 
+  /* Set the layer */
+  set_layer(LAYER_NETWORK);
+
   /*
    * Stats accounting
    */
