@@ -5,7 +5,7 @@
 **
 ** Comments: Dump ARP / RARP header information
 **
-** $Id: arp.c,v 1.18 2001/05/28 19:24:04 mborella Exp $
+** $Id: arp.c,v 1.19 2001/09/07 20:59:11 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -100,22 +100,20 @@ void dump_etherarp(packet_t *pkt)
   /*
    * Some ARPs include Ethernet frame padding.  Check for that.  Note that we
    * must allow ARP frames to be 1500 bytes.  Some NICs seems to generate 
-   * them as such.  Strange but true.
+   * them as such.  Strange but true.  In any case, we set the apparent end
+   * of the packet to be at the place where we stop processing legit ARP 
+   * bytes, and if padding is turned on, you'll see the rest of the bytes.
    */
   
- if (!my_args->m)
-   {
-     u_int8_t padding[ARP_PADDING_SIZE]; 
-     int bytes;
-
-     bytes = get_packet_bytesleft(pkt); 
-     if (bytes > ARP_PADDING_SIZE)
-       bytes = ARP_PADDING_SIZE;
-     if (!bytes || (get_packet_bytes((u_int8_t *) &padding, pkt, bytes) == 0))
-       return;
-     display("Padding", (u_int8_t *) &padding, bytes, DISP_HEX_MULTILINE);
-   }
-
+  if (!my_args->m)
+    {
+      int bytes;
+      
+      bytes = get_packet_apparentbytesleft(pkt); 
+      if (bytes > 0)
+	set_packet_apparentend(pkt, 0);
+    }
+  
 }
 
 /*----------------------------------------------------------------------------
