@@ -5,7 +5,7 @@
 **
 ** Comments: CHAP decoding.
 **
-** $Id: chap.c,v 1.6 2001/01/05 19:12:32 mborella Exp $
+** $Id: chap.c,v 1.7 2001/05/28 19:24:04 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -73,6 +73,9 @@ void dump_chap(packet_t *pkt)
 {
   chap_t chap;
   
+  /* Set the layer */
+  set_layer(LAYER_DATALINK);
+
   /*
    * Get the header
    */
@@ -90,19 +93,16 @@ void dump_chap(packet_t *pkt)
    * Dump the header
    */
   
-  if (!my_args->l)
+  if (my_args->m)
     {
-      if (my_args->m)
-	{
-	  display_minimal_string("| CHAP ");
-	}
-      else
-	{
-	  display_header_banner("CHAP Header");
-	  display_strmap("Code", chap.code, chap_code_map);
-	  display("Identifier", &chap.identifier, 1, DISP_DEC);
-	  display("Length", (u_int8_t *) &chap.length, 2, DISP_DEC);
-	}
+      display_minimal_string("| CHAP ");
+    }
+  else
+    {
+      display_header_banner("CHAP Header");
+      display_strmap("Code", chap.code, chap_code_map);
+      display("Identifier", &chap.identifier, 1, DISP_DEC);
+      display("Length", (u_int8_t *) &chap.length, 2, DISP_DEC);
     }
 
   /*
@@ -143,28 +143,25 @@ void dump_chap(packet_t *pkt)
 	name[name_size] = '\0';
 
 	/* display everything */
-	if (!my_args->l)
+	if (my_args->m)
 	  {
-	    if (my_args->m)
-	      {
-		if (chap.code == CHAP_CODE_CHALLENGE)
-		  display_minimal_string("challenge ");
-		if (chap.code == CHAP_CODE_RESPONSE)
-		  display_minimal_string("response ");
-		display_minimal_string("(");
-		display_minimal(value, value_size, DISP_HEX);
-		display_minimal_string(", ");
-		display_minimal_string(name);
-		display_minimal_string(")");
-	      }
-	    else
-	      {
-		display("Value size", &value_size, 1, DISP_DEC);
-		display("Value", value, value_size, DISP_HEX);
-		display_string("Name", name);
-	      }
-	  } /* if */
-
+	    if (chap.code == CHAP_CODE_CHALLENGE)
+	      display_minimal_string("challenge ");
+	    if (chap.code == CHAP_CODE_RESPONSE)
+	      display_minimal_string("response ");
+	    display_minimal_string("(");
+	    display_minimal(value, value_size, DISP_HEX);
+	    display_minimal_string(", ");
+	    display_minimal_string(name);
+	    display_minimal_string(")");
+	  }
+	else
+	  {
+	    display("Value size", &value_size, 1, DISP_DEC);
+	    display("Value", value, value_size, DISP_HEX);
+	    display_string("Name", name);
+	  }
+	
 	/* free memory */
 	my_free(value);
 	my_free(name);
@@ -188,23 +185,20 @@ void dump_chap(packet_t *pkt)
 	message[message_len] = '\0';
 
 	/* display it */
-	if (!my_args->l)
+	if (my_args->m)
 	  {
-	    if (my_args->m)
-	      {
-		if (chap.code == CHAP_CODE_SUCCESS)
-		  display_minimal_string("success ");
-		if (chap.code == CHAP_CODE_FAILURE)
-		  display_minimal_string("failure ");
-		display_minimal_string("(");
-		display_minimal_string(message);
-		display_minimal_string(")");
-	      }
-	    else
-	      {
-		display_string("Message", message);
-	      }
-	  } /* if */	
+	    if (chap.code == CHAP_CODE_SUCCESS)
+	      display_minimal_string("success ");
+	    if (chap.code == CHAP_CODE_FAILURE)
+	      display_minimal_string("failure ");
+	    display_minimal_string("(");
+	    display_minimal_string(message);
+	    display_minimal_string(")");
+	  }
+	else
+	  {
+	    display_string("Message", message);
+	  }
 
 	/* free memory */
 	my_free(message);
