@@ -5,7 +5,7 @@
 **
 ** Comments: Generic datalink module
 **
-** $Id: datalink.c,v 1.17 2001/04/02 18:04:52 mborella Exp $
+** $Id: datalink.c,v 1.20 2001/09/07 22:16:29 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -31,6 +31,7 @@
 #include "slip.h"
 #include "raw.h"
 #include "ppp.h"
+#include "padding.h"
 #include "payload.h"
 #include "stats.h"
 
@@ -62,10 +63,12 @@ void datalink(u_char *user, const struct pcap_pkthdr *h, u_char *pkt)
   start_of_packet = 1;
 
   /*
-   * Reset the stats counted flag
+   * Reset the stats counted flag and unpause the counting if paused.
+   * This avoids the double-counting of encapsulated headers.
    */
 
   stats_reset();
+  stats_unpause();
 
   /*
    * Determine real length of the data that we received
@@ -81,6 +84,7 @@ void datalink(u_char *user, const struct pcap_pkthdr *h, u_char *pkt)
   memcpy(packet.contents, pkt, len);
   packet.current = &packet.contents[0];
   packet.end = &packet.contents[0] + len;
+  packet.apparent_end = packet.end;
   packet.media_length = h->len;
   sprintf(packet.timestamp, "%u.%06u", (u_int32_t) h->ts.tv_sec, 
 	  (u_int32_t) h->ts.tv_usec);
@@ -141,14 +145,27 @@ void datalink(u_char *user, const struct pcap_pkthdr *h, u_char *pkt)
       error_fatal("\ncannot handle data link type %d", link);
     }
   
-  /*
-   * If there is any remaining data and the user wants to see it, dump it 
-   * out now
+  /* 
+   * Both payload and padding shouldn't be displayed in minimal mode 
    */
-  
-  if (my_args->p && get_packet_bytesleft(&packet))
-    dump_payload(&packet);
-  
+  if (!my_args->m)
+    {
+      /*
+       * If there is any remaining data and the user wants to see it, dump it 
+       * out now
+       */
+      
+      if (my_args->p && get_packet_apparentbytesleft(&packet))
+	dump_payload(&packet);
+      
+      /* 
+       * If there is a padding and the user wants to see it, dump it out now
+       */
+      
+      if (my_args->d && packet_haspadding(&packet))
+	dump_padding(&packet);
+    }
+
   /*
    * For minimal mode, finish with a carriage return
    */
