@@ -5,7 +5,7 @@
 **
 ** Comments: Dump DHCP header information.  See RFCs 2131 and 2132.
 **
-** $Id: dhcp.c,v 1.12 2001/05/28 19:24:04 mborella Exp $
+** $Id: dhcp.c,v 1.13 2001/09/07 20:59:11 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -217,7 +217,7 @@ void dump_dhcp(packet_t *pkt)
    * Parse the options list
    */
 
-  while (get_packet_bytesleft(pkt))
+  while (get_packet_apparentbytesleft(pkt))
     {     
       u_int8_t len=0;
       
