@@ -5,7 +5,7 @@
 **
 ** Comments: Displaying functions
 **
-** $Id: display.c,v 1.22 2001/05/18 21:54:16 mborella Exp $
+** $Id: display.c,v 1.23 2001/05/28 19:24:04 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -34,63 +34,40 @@
 int packet_displayed;
 int start_of_packet;
 
-extern struct arg_t *my_args;
-
+extern struct arg_t * my_args;
 
 /*----------------------------------------------------------------------------
 **
-** display_header_line_stars()
+** display_header_line()
 **
-** Writes out a line of asterisks meant to be part of a header
+** Writes out a line of separators (separators defined in headerline_t)
 **
 **----------------------------------------------------------------------------
 */
 
-inline void display_header_line_stars(void)
+inline void display_header_line(headerline_t hl)
 {
-  printf("**************************************************************************\n");
-}
-
-/*----------------------------------------------------------------------------
-**
-** display_header_line_dashes()
-**
-** Writes out a line of dashes meant to be part of a header
-**
-**----------------------------------------------------------------------------
-*/
-
-inline void display_header_line_dashes(void)
-{
-  printf("--------------------------------------------------------------------------\n");
-}
-
-/*----------------------------------------------------------------------------
-**
-** display_header_line_equals()
-**
-** Writes out a line of equals meant to be part of a header
-**
-**----------------------------------------------------------------------------
-*/
-
-inline void display_header_line_equals(void)
-{
-  printf("===========================================================================\n");
-}
-
-/*----------------------------------------------------------------------------
-**
-** display_header_line_dots()
-**
-** Writes out a line of dots meant to be part of a header
-**
-**----------------------------------------------------------------------------
-*/
-
-inline void display_header_line_dots(void)
-{
-  printf("...........................................................................\n");
+  /* Check the layer */
+  if (check_layer())
+    return;
+  
+  switch(hl)
+    {
+    case HEADERLINE_DASHES:
+      printf("--------------------------------------------------------------------------\n");
+      break;
+    case HEADERLINE_STARS:
+      printf("**************************************************************************\n");
+      break;
+    case HEADERLINE_EQUALS:
+      printf("==========================================================================\n");
+      break;
+    case HEADERLINE_DOTS:
+      printf("..........................................................................\n");
+      break;
+    default:
+      error_fatal("unknown header line type");
+    }
 }
 
 /*----------------------------------------------------------------------------
@@ -107,20 +84,24 @@ inline void display_header_line_dots(void)
 
 inline void display_header_banner_ts(char *banner, char *ts)
 {
+  /* Check the layer */
+  if (check_layer())
+    return;
+
   if (start_of_packet)
     {
-      display_header_line_stars();
+      display_header_line(HEADERLINE_STARS);
       start_of_packet = 0;
     }
   else
-    display_header_line_dashes();
+    display_header_line(HEADERLINE_DASHES);
 
   printf("                        %s", banner);
   if (ts == NULL)
     printf("\n");
   else
     printf(" (%s)\n", ts);
-  display_header_line_dashes();
+  display_header_line(HEADERLINE_DASHES);
 }
 
 /*----------------------------------------------------------------------------
@@ -132,7 +113,7 @@ inline void display_header_banner_ts(char *banner, char *ts)
 **----------------------------------------------------------------------------
 */
 
-inline void display_header_banner(char *banner)
+inline void display_header_banner(char * banner)
 {
   display_header_banner_ts(banner, NULL);
 }
@@ -151,6 +132,10 @@ inline void display_whitespace_pad(int length)
 {
   int i;
 
+  /* Check the layer */
+  if (check_layer())
+    return;
+
   for (i=0; i < LABEL_LENGTH+1-length; i++)
     putchar(' ');
 }
@@ -176,6 +161,10 @@ inline void display(char * label, u_int8_t * content, u_int8_t length,
   int label_len;
   char label_truncated[LABEL_LENGTH+1];
 
+  /* Check the layer */
+  if (check_layer())
+    return;
+
   /*
    * Do sanity checks here
    */
@@ -234,6 +223,10 @@ inline void display_minimal(u_int8_t * content, u_int8_t length,
   u_int32_t        multiplier;
   int              len;
 
+  /* Check the layer */
+  if (check_layer())
+    return;
+
   /*
    * We have displayed part of this packet, so we need a carriage return.
    */
@@ -418,14 +411,14 @@ inline void display_minimal_string(u_int8_t * content)
 ** display_string()
 **
 ** Same as display() but we assume that the content argument is 
-** a string.
+** a string.  We also assume multiline support is required.
 **
 **----------------------------------------------------------------------------
 */
 
 inline void display_string(u_int8_t * label, u_int8_t * content)
 {
-  display(label, content, strlen(content), DISP_STRING);
+  display(label, content, strlen(content), DISP_STRING_MULTILINE);
 }
 
 /*----------------------------------------------------------------------------
@@ -539,6 +532,10 @@ inline void display_minimal_ipv6(u_int8_t * content)
 
 inline void display_minimal_cr(void)
 {
+  /* Check the layer */
+  if (check_layer())
+    return;
+
   printf("\n");
 }
 
