@@ -5,7 +5,7 @@
 **
 ** Comments: Header file for displaying functions
 ** 
-** $Id: display.h,v 1.18 2001/05/18 15:30:53 mborella Exp $
+** $Id: display.h,v 1.19 2001/05/28 19:24:04 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -29,6 +29,8 @@
 #include "global.h"
 #include "strmap.h"
 #include "utilities.h"
+#include "layers.h"
+#include "error.h"
 
 
 /*
@@ -49,14 +51,23 @@ typedef enum display
   DISP_STRING_MULTILINE /* String output spanning more than one line */
 } display_t;
 
+/*
+ * Header line types
+ */
+
+typedef enum headerline
+{
+  HEADERLINE_DASHES,
+  HEADERLINE_STARS,
+  HEADERLINE_EQUALS,
+  HEADERLINE_DOTS,  
+} headerline_t;
+
 /*
  * Function prototypes
  */
 
-inline void display_header_line_dashes (void);
-inline void display_header_line_stars (void);
-inline void display_header_line_equals (void);
-inline void display_header_line_dots (void);
+inline void display_header_line (headerline_t);
 inline void display_header_banner (char *);
 inline void display_header_banner_ts(char *, char *);
 inline void display (char *, u_int8_t *, u_int8_t, display_t);
