@@ -5,7 +5,7 @@
 **
 ** Comments: Dump DNS header information
 **
-** $Id: dns.c,v 1.19 2001/01/20 00:30:31 mborella Exp $
+** $Id: dns.c,v 1.20 2001/05/28 19:24:04 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -299,6 +299,9 @@ void dump_dns(packet_t *pkt)
   u_int8_t f_qr, f_opcode, f_aa, f_tc, f_rd, f_ra, f_zero, f_rcode;
   char holder[64];
 
+  /* Set the layer */
+  set_layer(LAYER_APPLICATION);
+
   /*
    * Mark the beginning of the DNS portion so that labels can be stored
    * properly
