@@ -7,7 +7,7 @@
 ** Comments: Support for dynamic port mapping.  This allows a protocol to
 ** to listened for on a non-standard port.
 **
-** $Id: dynports.c,v 1.1 2001/04/02 23:18:28 mborella Exp $
+** $Id: dynports.c,v 1.2 2001/04/26 23:49:50 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -85,11 +85,38 @@ void dynports_parse(char *s)
   
   /* determine protocol */
   *ptr = '\0';
-  if (!strcmp(s, "rtp"))
-    f = dump_rtp;
+  f = NULL;
+  if (!strcmp(s, "dhcp"))
+    f = dump_dhcp;
+  if (!strcmp(s, "dns"))
+    f = dump_dns;
+  if (!strcmp(s, "http"))
+    f = dump_http;
+  if (!strcmp(s, "isakmp"))
+    f = dump_isakmp;
+  if (!strcmp(s, "l2tp"))
+    f = dump_l2tp;
+  if (!strcmp(s, "mgcp"))
+    f = dump_mgcp;
   if (!strcmp(s, "mobileip"))
     f = dump_mobileip;
-  else 
+  if (!strcmp(s, "netbios_ns"))
+    f = dump_netbios_ns;
+  if (!strcmp(s, "pptp"))
+    f = dump_pptp;
+  if (!strcmp(s, "rip"))
+    f = dump_rip;
+  if (!strcmp(s, "ripng"))
+    f = dump_ripng;
+  if (!strcmp(s, "rtp"))
+    f = dump_rtp;
+  if (!strcmp(s, "sip"))
+    f = dump_sip;
+  if (!strcmp(s, "snmp"))
+    f = dump_snmp;
+  if (!strcmp(s, "slp"))
+    f = dump_slp;
+  if (f==NULL)
     error_fatal("dynamic port assignment to unknown protocol %s", s);
 
   dynports_add(port, f);
