@@ -5,7 +5,7 @@
 **
 ** Comments: Hex buffer manipulation routines
 **
-** $Id: hexbuffer.c,v 1.4 2001/05/18 15:30:53 mborella Exp $
+** $Id: hexbuffer.c,v 1.5 2001/05/28 19:24:04 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -118,7 +118,7 @@ inline void hexbuffer_flush(void)
   buf_end = &hexbuffer[current_ptr];
 
   /* display some dots as a separator */
-  display_header_line_dots();
+  display_header_line(HEADERLINE_DOTS);
 
   /* loop through the hex buffer, printing a line at a time */
   do
@@ -143,7 +143,8 @@ inline void hexbuffer_flush(void)
               buf_ptr++;
             }
         }
-      printf("%-48s %s\n", temp_hexbuf, temp_charbuf);
+      if (!check_layer())
+	printf("%-48s %s\n", temp_hexbuf, temp_charbuf);
     }
   while(buf_ptr < buf_end);
   
