@@ -5,7 +5,7 @@
 **
 ** Comments: Dump IGMP information
 **
-** $Id: igmp.c,v 1.9 2001/04/02 17:41:01 mborella Exp $
+** $Id: igmp.c,v 1.10 2001/05/28 19:24:04 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -55,6 +55,9 @@ void dump_igmp(packet_t *pkt)
   igmp_header_t igmp;
   char holder[64];
 
+  /* Set the layer */
+  set_layer(LAYER_NETWORK);
+
   /*
    * Stats accounting
    */
@@ -80,7 +83,7 @@ void dump_igmp(packet_t *pkt)
    * Dump the contents
    */
 
-  if (my_args->m && !my_args->n)
+  if (my_args->m)
     {
       /* In minimal mode lets just dump the type and address */
       display_minimal_string("| IGMP ");
@@ -88,26 +91,25 @@ void dump_igmp(packet_t *pkt)
       display_minimal_string(" ");
     }
   else
-    if (!my_args->n)
-      { 
-	/* announcement */
-	display_header_banner("IGMP Header");
-	
-	/* Dump the type, max resp time, checksum and address */
-	sprintf(holder, "%d (%s)", igmp.type, 
-		map2str(igmp_type_map, igmp.type));
-	display_string("Type", holder);
-	display("Max response time", (u_int8_t *) &igmp.max_resp_time, 1,
-		DISP_DEC);
-	display("Checksum", (u_int8_t *) &igmp.checksum, 2, DISP_DEC);
-	
-	/*
-	 * We currently don't try to interpret DVMRP packets...
-	 */
-
-	if (igmp.type != IGMP_TYPE_DVMRP)
-	  display_ipv4("Group address", (u_int8_t *) &igmp.address);
-      }
+    { 
+      /* announcement */
+      display_header_banner("IGMP Header");
+      
+      /* Dump the type, max resp time, checksum and address */
+      sprintf(holder, "%d (%s)", igmp.type, 
+	      map2str(igmp_type_map, igmp.type));
+      display_string("Type", holder);
+      display("Max response time", (u_int8_t *) &igmp.max_resp_time, 1,
+	      DISP_DEC);
+      display("Checksum", (u_int8_t *) &igmp.checksum, 2, DISP_DEC);
+      
+      /*
+       * We currently don't try to interpret DVMRP packets...
+       */
+      
+      if (igmp.type != IGMP_TYPE_DVMRP)
+	display_ipv4("Group address", (u_int8_t *) &igmp.address);
+    }
 }
 
 
