@@ -5,7 +5,7 @@
 **
 ** Comments: Functions to handle certain IP protocol numbers
 **
-** $Id: ip_services.c,v 1.6 2001/01/20 00:30:31 mborella Exp $
+** $Id: ip_services.c,v 1.8 2001/04/02 23:18:28 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -25,6 +25,7 @@
 
 #include "global.h"
 #include "ip_services.h"
+#include "dynports.h"
 
 /*
  * We'll put the port map here even though it is used by TCP and UDP.
@@ -84,6 +85,7 @@ strmap_t port_map[] =
   { PORT_ISAKMP,           "ISAKMP/IKE" },
   { PORT_RIP,              "RIP" },
   { PORT_RIPNG,            "RIPng" },
+  { PORT_CDMA2000A11,      "CDMA2000 A11" },
 
   { PORT_L2TP,             "L2TP" },
   { PORT_PPTP,             "PPTP" },
@@ -93,6 +95,8 @@ strmap_t port_map[] =
 };
 
 
+extern struct arg_t * my_args;
+
 /*----------------------------------------------------------------------------
 **
 ** port2func(u_int16_t)
@@ -104,70 +108,81 @@ strmap_t port_map[] =
 
 service_func_t port2func(u_int16_t port)
 {
-  service_func_t f;
+  service_func_t f = NULL;
 
-  switch(port)
+  /* Check for dynamic mappings */
+  if (my_args->P)
+    f = dynports_find(port);
+  
+  if (f == NULL)
     {
-    case PORT_SSH:
-      f = dump_ssh;
-      break;
-
-    case PORT_SIP:
-      f = dump_sip;
-      break;
+      switch(port)
+	{
+	case PORT_SSH:
+	  f = dump_ssh;
+	  break;
+	  
+	case PORT_SIP:
+	  f = dump_sip;
+	  break;
+	  
+	case PORT_DNS:
+	  f = dump_dns;
+	  break;
+	  
+	case PORT_DHCPCLIENT:
+	case PORT_DHCPSERVER:
+	  f = dump_dhcp;
+	  break;
+	  
+	case PORT_HTTP:
+	  f = dump_http;
+	  break;
       
-    case PORT_DNS:
-      f = dump_dns;
-      break;
+	case PORT_NETBIOSNS:
+	  f = dump_netbios_ns;
+	  break;
 
-    case PORT_DHCPCLIENT:
-    case PORT_DHCPSERVER:
-      f = dump_dhcp;
-      break;
-
-    case PORT_HTTP:
-      f = dump_http;
-      break;
-
-    case PORT_NETBIOSNS:
-      f = dump_netbios_ns;
-      break;
-
-    case PORT_SNMP:
-      f = dump_snmp;
-      break;
-
-    case PORT_SLP:
-      f = dump_slp;
-      break;
-
-    case PORT_MOBILEIP:
-      f = dump_mobileip;
-      break;
-
-    case PORT_ISAKMP:
-      f = dump_isakmp;
-      break;
-
-    case PORT_RIP:
-      f = dump_rip;
-      break;
-
-    case PORT_RIPNG:
-      f = dump_ripng;
-      break;
-
-    case PORT_L2TP:
-      f = dump_l2tp;
-      break;
-
-    case PORT_PPTP:
-      f = dump_pptp;
-      break;
-
-    default:
-      f = NULL;
-      break;
+	case PORT_SNMP:
+	  f = dump_snmp;
+	  break;
+	  
+	case PORT_SLP:
+	  f = dump_slp;
+	  break;
+	  
+	case PORT_MOBILEIP:
+	  f = dump_mobileip;
+	  break;
+	  
+	case PORT_ISAKMP:
+	  f = dump_isakmp;
+	  break;
+      
+	case PORT_RIP:
+	  f = dump_rip;
+	  break;
+	  
+	case PORT_RIPNG:
+	  f = dump_ripng;
+	  break;
+	  
+	case PORT_CDMA2000A11:
+	  f = dump_mobileip;
+	  break;
+	  
+	case PORT_L2TP:
+	  f = dump_l2tp;
+	  break;
+	  
+	case PORT_PPTP:
+	  f = dump_pptp;
+	  break;
+      
+	default:
+	  f = NULL;
+	  break;
+	}
     }
 
   return f;
