@@ -7,7 +7,7 @@
 ** Sniffs all packets on the link and dumps the fields of the data link, 
 ** IP, TCP, and UDP headers.  
 **
-** $Id: ipgrab.c,v 1.14 2001/04/02 23:18:28 mborella Exp $
+** $Id: ipgrab.c,v 1.15 2001/05/28 19:24:04 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -62,6 +62,12 @@ int main(int argc, char *argv[])
   init_ip_protocols();
   stats_init();
 
+  /*
+   * Set the layer
+   */
+
+  set_layer(LAYER_NONE);
+
   /*
    * Clear packet count
    */
