@@ -5,7 +5,7 @@
 **
 ** Comments: Dump IP header information
 **
-** $Id: ipv6.c,v 1.11 2001/04/02 17:41:01 mborella Exp $
+** $Id: ipv6.c,v 1.12 2001/05/28 19:24:04 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -47,6 +47,9 @@ void dump_ipv6(packet_t *pkt)
   u_int8_t      class; 
   u_int32_t     flow;
 
+  /* Set the layer */
+  set_layer(LAYER_NETWORK);
+
   /*
    * Stats accounting
    */
@@ -88,24 +91,23 @@ void dump_ipv6(packet_t *pkt)
       display_minimal_string(" ");
     }
   else
-    if (!my_args->n)
-      {
-	/* announcement */
-	display_header_banner("IPv6 Header");
-	
-	/* print fields */
-	display("Version", (u_int8_t *) &ver, 1, DISP_DEC);
-	display("Traffic class", (u_int8_t *) &class, 1, DISP_HEX);
-	display("Flow label", (u_int8_t *) &flow, 4, DISP_HEX);
-	display("Payload length", (u_int8_t *) &ipv6.payload_length, 2, 
-		DISP_DEC);
-	sprintf(holder, "%d (%s)", ipv6.next_header, 
-		map2str(ipproto_map, ipv6.next_header));
-	display("Next header", holder, strlen(holder), DISP_STRING);
-	display("Hop limit", (u_int8_t *) &ipv6.hop_limit, 1, DISP_DEC);
-	display_ipv6("Source address",(u_int8_t *) &ipv6.src_addr); 
-	display_ipv6("Destination address",(u_int8_t *) &ipv6.dst_addr); 
-      }
+    {
+      /* announcement */
+      display_header_banner("IPv6 Header");
+      
+      /* print fields */
+      display("Version", (u_int8_t *) &ver, 1, DISP_DEC);
+      display("Traffic class", (u_int8_t *) &class, 1, DISP_HEX);
+      display("Flow label", (u_int8_t *) &flow, 4, DISP_HEX);
+      display("Payload length", (u_int8_t *) &ipv6.payload_length, 2, 
+	      DISP_DEC);
+      sprintf(holder, "%d (%s)", ipv6.next_header, 
+	      map2str(ipproto_map, ipv6.next_header));
+      display("Next header", holder, strlen(holder), DISP_STRING);
+      display("Hop limit", (u_int8_t *) &ipv6.hop_limit, 1, DISP_DEC);
+      display_ipv6("Source address",(u_int8_t *) &ipv6.src_addr); 
+      display_ipv6("Destination address",(u_int8_t *) &ipv6.dst_addr); 
+    }
 
   /* dump the hex buffer */
   hexbuffer_flush();
