@@ -5,7 +5,7 @@
 **
 ** Dump IPX header information
 **
-** $Id: ipx.c,v 1.11 2001/04/02 17:41:01 mborella Exp $
+** $Id: ipx.c,v 1.12 2001/05/28 19:24:04 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -60,6 +60,9 @@ void dump_ipx(packet_t *pkt)
   ipx_header_t ipx;
   char holder[64];
  
+  /* Set the layer */
+  set_layer(LAYER_NETWORK);
+
   /*
    * Stats accounting
    */
@@ -97,41 +100,39 @@ void dump_ipx(packet_t *pkt)
       display_minimal_string(" ");      
     }
   else 
-    if (!my_args->n)
-      {
-	/* announcement */
-	display_header_banner("IPX Header");
-	
-	/* Checksum, length, transport */
-	display("Checksum", (u_int8_t *) &ipx.csum, 2, DISP_DEC);
-	display("Packet length", (u_int8_t *) &ipx.len, 2, DISP_DEC);
-	display("Transport control", (u_int8_t *) &ipx.tc, 1, DISP_DEC);
-	
-	/* packet type */
-	sprintf(holder, "%d (%s)", ipx.pt, 
-		map2str(ipx_packettype_map, ipx.pt));
-	display("Packet type", (u_int8_t *) holder, strlen(holder), 
-		DISP_STRING);
-	
-	/* destination network information */
-	display("Destination network", (u_int8_t *) &ipx.dstnet, 2, 
-		DISP_DEC);
-	display("Destination node", (u_int8_t *) &ipx.dstnode, 6, 
-		DISP_HEXCOLONS);
-	display("Destination port", (u_int8_t *) &ipx.dstport, 2, 
-		DISP_DEC);
-	
-	/* source network information */
-	display("Source network", (u_int8_t *) &ipx.srcnet, 2, 
-		DISP_DEC);
-	display("Source node", (u_int8_t *) &ipx.srcnode, 6, 
-		DISP_HEXCOLONS);
-	display("Source port", (u_int8_t *) &ipx.srcport, 2, DISP_DEC);
-      }
+    {
+      /* announcement */
+      display_header_banner("IPX Header");
+      
+      /* Checksum, length, transport */
+      display("Checksum", (u_int8_t *) &ipx.csum, 2, DISP_DEC);
+      display("Packet length", (u_int8_t *) &ipx.len, 2, DISP_DEC);
+      display("Transport control", (u_int8_t *) &ipx.tc, 1, DISP_DEC);
+      
+      /* packet type */
+      sprintf(holder, "%d (%s)", ipx.pt, 
+	      map2str(ipx_packettype_map, ipx.pt));
+      display("Packet type", (u_int8_t *) holder, strlen(holder), 
+	      DISP_STRING);
+      
+      /* destination network information */
+      display("Destination network", (u_int8_t *) &ipx.dstnet, 2, 
+	      DISP_DEC);
+      display("Destination node", (u_int8_t *) &ipx.dstnode, 6, 
+	      DISP_HEXCOLONS);
+      display("Destination port", (u_int8_t *) &ipx.dstport, 2, 
+	      DISP_DEC);
+      
+      /* source network information */
+      display("Source network", (u_int8_t *) &ipx.srcnet, 2, 
+	      DISP_DEC);
+      display("Source node", (u_int8_t *) &ipx.srcnode, 6, 
+	      DISP_HEXCOLONS);
+      display("Source port", (u_int8_t *) &ipx.srcport, 2, DISP_DEC);
+    }
   
   /* dump the hex buffer */
-  if (!my_args->n)
-    hexbuffer_flush();
+  hexbuffer_flush();
 
   /*
    * Hand it to the next higher layer protocol.
