@@ -6,7 +6,7 @@
 **
 ** Comments: Dump L2TP header information
 **
-** $Id: l2tp.c,v 1.8 2000/11/07 19:46:09 mborella Exp $
+** $Id: l2tp.c,v 1.9 2001/05/28 19:24:04 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -438,6 +438,9 @@ void dump_l2tp(packet_t *pkt)
   u_int16_t bytes_read = 0;
   u_int16_t length;
 
+  /* Set the layer */
+  set_layer(LAYER_APPLICATION);
+
   /*
    * Read the first byte, determine what to do next
    */
