@@ -5,7 +5,7 @@
 **
 ** Comments: LCP module.
 **
-** $Id: lcp.c,v 1.8 2001/01/05 19:12:32 mborella Exp $
+** $Id: lcp.c,v 1.9 2001/05/28 19:24:04 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -163,6 +163,9 @@ void dump_lcp(packet_t *pkt)
 {
   lcp_t lcp;
 
+  /* Set the layer */
+  set_layer(LAYER_DATALINK);
+
   /*
    * Get the header
    */
@@ -180,21 +183,18 @@ void dump_lcp(packet_t *pkt)
    * Dump the header
    */
 
-  if (!my_args->l)
+  if (my_args->m)
     {
-      if (my_args->m)
-	{
-	  display_minimal_string("| LCP ");
-	  display_minimal_string(map2str(lcp_code_map, lcp.code));
-	  display_minimal_string(" ");
-	}
-      else
-	{
-	  display_header_banner("LCP Header");
-	  display_strmap("Code", lcp.code, lcp_code_map);
-	  display("Identifier", &lcp.identifier, 1, DISP_DEC);
-	  display("Length", (u_int8_t *) &lcp.length, 2, DISP_DEC);
-	}
+      display_minimal_string("| LCP ");
+      display_minimal_string(map2str(lcp_code_map, lcp.code));
+      display_minimal_string(" ");
+    }
+  else
+    {
+      display_header_banner("LCP Header");
+      display_strmap("Code", lcp.code, lcp_code_map);
+      display("Identifier", &lcp.identifier, 1, DISP_DEC);
+      display("Length", (u_int8_t *) &lcp.length, 2, DISP_DEC);
     }
 
   /*
@@ -257,17 +257,14 @@ void dump_lcp(packet_t *pkt)
 		 * Display the type and length
 		 */
 		
-		if (!my_args->l)
+		if (my_args->m)
 		  {
-		    if (my_args->m)
-		      {
-			display_minimal_string(map2str(lcp_option_map, type));
-		      }
-		    else
-		      {
-			display_strmap("Option", type, lcp_option_map);
-			display("  Length", &length, 1, DISP_DEC);
-		      }
+		    display_minimal_string(map2str(lcp_option_map, type));
+		  }
+		else
+		  {
+		    display_strmap("Option", type, lcp_option_map);
+		    display("  Length", &length, 1, DISP_DEC);
 		  }
 		
 		/*
@@ -285,19 +282,16 @@ void dump_lcp(packet_t *pkt)
 		     * Display the value
 		     */
 
-		    if (!my_args->l)
+		    if (my_args->m)
 		      {
-			if (my_args->m)
-			  {
-			    display_minimal_string(" ");
-			    display_minimal(value, length-2, DISP_HEX);
-			  }
-			else
-			  {
-			    display("  Value", (u_int8_t *) value, length-2,
-				    DISP_HEX);
-			  }
-		      } /* if */
+			display_minimal_string(" ");
+			display_minimal(value, length-2, DISP_HEX);
+		      }
+		    else
+		      {
+			display("  Value", (u_int8_t *) value, length-2,
+				DISP_HEX);
+		      }
 		  } /* if */
 		
 	      } /* while */
@@ -336,7 +330,7 @@ void dump_lcp(packet_t *pkt)
 		  }
 	
 		/* dump it out as hex, but don't dump in minimal mode */
-		if (!my_args->l && !my_args->m)
+		if (!my_args->m)
 		  {
 		    display("Data", data, data_len, DISP_HEX);
 		  }
@@ -361,18 +355,15 @@ void dump_lcp(packet_t *pkt)
 	      return;
 
 	    /* display it */
-	    if (!my_args->l)
+	    if (my_args->m)
 	      {
-		if (my_args->m)
-		  {
-		    display_minimal((u_int8_t *) &magic_number, 4, DISP_HEX);
-		    display_minimal_string(" ");
-		  }
-		else
-		  {
-		    display("Magic number", (u_int8_t *) &magic_number, 4, 
-			    DISP_HEX);
-		  }
+		display_minimal((u_int8_t *) &magic_number, 4, DISP_HEX);
+		display_minimal_string(" ");
+	      }
+	    else
+	      {
+		display("Magic number", (u_int8_t *) &magic_number, 4, 
+			DISP_HEX);
 	      }
 
 	    /* Read the data, if any */
@@ -391,7 +382,7 @@ void dump_lcp(packet_t *pkt)
 		data[data_len] = '\0';
 
 		/* dump it out as hex, but don't dump in minimal mode */
-		if (!my_args->l && !my_args->m)
+		if (!my_args->m)
 		  {
 		    if (isprint_str(data, data_len))
 		      display_string("Data", data);
