@@ -5,7 +5,7 @@
 **
 ** Comments: Includes the ipgrab header files commonly needed.
 **
-** $Id: local.h,v 1.3 2001/04/02 17:41:01 mborella Exp $
+** $Id: local.h,v 1.4 2001/05/28 19:24:04 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -33,9 +33,7 @@
 #include "hexbuffer.h"
 #include "utilities.h"
 #include "stats.h"
-
-#define EXTRACT_16BITS(p) ((u_int16_t) ntohs (*(u_int16_t *)(p)))
-#define EXTRACT_32BITS(p) ((u_int32_t) ntohl (*(u_int32_t *)(p)))
+#include "layers.h"
 
 /*
  * This is a stupid hack to get around forcing signal handlers to take
