@@ -5,7 +5,7 @@
 **
 ** Comments: 
 **
-** $Id: mobileip.c,v 1.9 2001/05/28 19:24:04 mborella Exp $
+** $Id: mobileip.c,v 1.10 2001/09/07 20:59:11 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -645,7 +645,7 @@ void dump_mobileip(packet_t *pkt)
    * problems by assuming that there is a valid length after the type.
    */
 
-  while (get_packet_bytesleft(pkt))
+  while (get_packet_apparentbytesleft(pkt))
     {
       u_int8_t type;
 
