@@ -2,7 +2,7 @@
 **
 ** parse_cl.h
 **
-** Mon May 28 14:27:48 2001
+** Fri Sep  7 14:32:42 2001
 ** Linux 2.4.2 (#5 Thu Apr 26 12:29:16 CDT 2001) i686
 ** mborella@stratos (Mike Borella)
 **
@@ -29,6 +29,7 @@ struct arg_t
   bool a;
   bool b;
   int c;
+  bool d;
   char * i;
   bool l;
   bool m;
