@@ -5,7 +5,7 @@
 **
 ** Comments: PPP module.
 **
-** $Id: ppp.c,v 1.8 2000/10/02 22:33:58 mborella Exp $
+** $Id: ppp.c,v 1.9 2001/05/28 19:24:04 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -81,6 +81,9 @@ void dump_ppp(packet_t *pkt)
   u_int16_t protocol;
   u_int16_t two_bytes;
 
+  /* Set the layer */
+  set_layer(LAYER_DATALINK);
+
   /*
    * Look at the first 2 bytes to see if address/control compression is 
    * set or not.
@@ -115,21 +118,17 @@ void dump_ppp(packet_t *pkt)
        * Dump the header
        */
       
-      if (!my_args->l)
+      if (my_args->m)
 	{
-	  if (my_args->m)
-	    {
-	      display_minimal_string("| PPP ");
-	    }
-	  else
-	    {
-	      display_header_banner("PPP Header");
-	      display("Address", &ppp.address, 1, DISP_HEX);
-	      display("Control", &ppp.control, 1, DISP_HEX);
-	      display_strmap_hex("Protocol type", protocol, 
-				 ppp_protocol_map);
-	    }
-	  
+	  display_minimal_string("| PPP ");
+	}
+      else
+	{
+	  display_header_banner("PPP Header");
+	  display("Address", &ppp.address, 1, DISP_HEX);
+	  display("Control", &ppp.control, 1, DISP_HEX);
+	  display_strmap_hex("Protocol type", protocol, 
+			     ppp_protocol_map);
 	}
     }
   else
@@ -164,23 +163,19 @@ void dump_ppp(packet_t *pkt)
        * Dump the header
        */
       
-      if (!my_args->l)
+      if (my_args->m)
 	{
-	  if (my_args->m)
-	    {
-	      display_minimal_string("PPP ");
-	    }
-	  else
-	    {
-	      display_header_banner("PPP Header");
-	      display_strmap_hex("Protocol type", protocol, ppp_protocol_map);
-	    }
+	  display_minimal_string("PPP ");
+	}
+      else
+	{
+	  display_header_banner("PPP Header");
+	  display_strmap_hex("Protocol type", protocol, ppp_protocol_map);
 	}
     } /* else */
 
   /* dump the hex buffer */
-  if (!my_args->l)
-    hexbuffer_flush();
+  hexbuffer_flush();
   
   /*
    * Determine the next layer protocol
