@@ -5,7 +5,7 @@
 **
 ** Comments: Dump RIPng header information. 
 **
-** $Id: ripng.c,v 1.6 2001/03/27 20:45:36 mborella Exp $
+** $Id: ripng.c,v 1.7 2001/05/28 19:24:04 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -55,8 +55,11 @@ void dump_ripng(packet_t *pkt)
   char                 holder[64];
   int                  route_count;
 
+  /* Set the layer */
+  set_layer(LAYER_APPLICATION);
+
   /*
-   * Get the RIP v2 static header
+   * Get the RIPng static header
    */
       
   if (get_packet_bytes((u_int8_t *) &ripng, pkt, sizeof(ripng_header_t)) == 0)
