@@ -6,7 +6,7 @@
 **
 ** Comments: Dump TCP header information. 
 **
-** $Id: tcp.c,v 1.20 2001/05/28 19:24:04 mborella Exp $
+** $Id: tcp.c,v 1.21 2001/09/07 20:59:11 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -337,7 +337,7 @@ void dump_tcp(packet_t *pkt)
    * data
    */
 
-  if (get_packet_bytesleft(pkt))
+  if (get_packet_apparentbytesleft(pkt))
     {
       /*
        * Let's see if we can decode the application from the source port...
