@@ -5,7 +5,7 @@
 **
 ** Comments: Dump UDP header information
 **
-** $Id: udp.c,v 1.15 2001/04/02 17:41:01 mborella Exp $
+** $Id: udp.c,v 1.16 2001/05/28 19:24:04 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -45,6 +45,9 @@ void dump_udp(packet_t *pkt)
   udp_header_t udp;
   service_func_t app;
 
+  /* Set the layer */
+  set_layer(LAYER_TRANSPORT);
+
   /*
    * Stats accounting
    */
